package org.colinvella.fancyfish.item.tool;

import net.minecraft.item.ItemStack;
import net.minecraft.util.BlockPos;
import net.minecraft.world.World;

import org.colinvella.fancyfish.achievement.ModAchievements;

import net.minecraft.block.state.IBlockState;
import net.minecraft.entity.item.EntityItem;
import net.minecraft.entity.player.EntityPlayer;
import net.minecraft.init.Items;
import net.minecraft.item.Item;
import net.minecraft.item.Item.ToolMaterial;
import net.minecraftforge.common.util.EnumHelper;

public class FishScaleHoeItem extends ModItemHoe
{
	public static final String ID = "FishScaleHoe";
	
	public FishScaleHoeItem()
	{
		super(ID, Material);
	}

	@Override
	public boolean hasEffect(ItemStack stack)
	{
		// shimmers
		return true;
	};
	
	// trigger achievement for crafting hoe
	@Override
	public void onCreated(ItemStack stack, World worldIn, EntityPlayer playerIn)
	{
		playerIn.addStat(ModAchievements.BuildFishScaleHoe, 1);
	}
	
	@Override
	protected boolean useHoe(ItemStack stack, EntityPlayer player, World world, BlockPos target, IBlockState newState)
	{
		boolean result = super.useHoe(stack, player, world, target, newState);
		
		// if not successful, or on client side, nothing to spawn
		if (!result || world.isRemote)
			return result;
		
		// if hoed successfully, there's a 50% chance of spawning a crop seed
		// if the crop is a carrot, it has a 10% chance of being a golden one
		int random = this.itemRand.nextInt(100);
		int randomCrop = random/10;
		Item cropItem = null;
		switch (randomCrop)
		{
		case 0: cropItem = Items.wheat_seeds; break;
		case 1: cropItem = Items.melon_seeds; break;
		case 2: cropItem = Items.pumpkin_seeds; break;
		case 3: cropItem = Items.potato; break;
		case 4:
			cropItem = random % 10 == 0 ? Items.golden_carrot : Items.carrot;
			break;
		}
		
		if (cropItem == null)
			return result;
		
		double itemX = target.getX() + 0.5;
		double itemY = target.getY() + 0.1;
		double itemZ = target.getZ() + 0.5;
		
		world.spawnEntityInWorld(new EntityItem(world, itemX, itemY, itemZ, new ItemStack(cropItem)));
		
		if (!world.isRemote)
		{
			String soundId = cropItem == Items.golden_carrot ? "random.levelup" : "random.orb";
			world.playSoundEffect(itemX, itemY, itemZ, soundId, 1.0F, 0.8f);
		}
		
		return result;
	};
	
	
	private static final int HarvestLevel = 0;
	private static final int Durability = 1200;
	private static final float MiningSpeed = 1.0f;
	private static final int DamageVsEntities = 1;
	private static final int Enchantability = 25;
	
	private static final ToolMaterial Material = EnumHelper.addToolMaterial(
			"FishScale", HarvestLevel, Durability, MiningSpeed,
			DamageVsEntities, Enchantability);
}
